FILE:		nipros.man
DESCRIPTION:    Manual on the application of Tpros to yield stress data from
		nickel-based superalloys.
AUTHOR:		Dr. Franck Tancret / C.A. Walsh
LAST MOD DATE:	10/06/1999

Tpros is the Gaussian Process program written by Mark Gibbs and David MacKay.
This file describes the application of this program to predict the yield stress of
nickel-base superalloys.

##################################################################################
 1.                         Introduction to the Problem                     
##################################################################################

The problem we are interested in is that of predicting the yield stress of
nickel-based superalloys. This prediction is made as a function of temperature
and the elemental composition. The modelling procedure is a purely empirical one;
i.e. the model is trained on a set of experimental data for which the "outputs"
are known, and creates a kind of non-linear, multi-parameter "regression" of the
outputs versus the inputs. This "regression" has already been produced and the
model is delivered ready to perform predictions for nickel-based alloys of any
desired composition (within certain specified limits). A perusal of the paper by
Tancret et al. [1] is strongly recommended before proceeding further. It provides
details about the database, the model and its use.

##################################################################################
 2.                      Downloading Tpros and Data Files                  
##################################################################################

MAP provides a set of data files which can be used with the Tpros program for 
calculating the yield stress. The Tpros program itself is not included with this
distribution, as we do not maintain it. We cannot, therefore, be responsible for
any failures due to backward compatibility with later versions of Tpros. 

2.1 The Tpros program.
----------------------

Tpros is an ANSI C program for UNIX/Linux machines. It can be downloaded from the 
following web site:

          http://wol.ra.phy.cam.ac.uk/mng10/GP/GP.html

It is in the form of a zipped TAR file (Tpros.tar.gz), which is best placed in a 
separate directory (e.g. /gauss) before uncompressing it. To uncompress the file 
type:

gunzip Tpros.tar.gz	(creates the Tpros.tar file)

and then:

tar -xvf Tpros.tar	(extracts the entire Tpros package)

It contains 7 directories:

/ansi           - Contains several subroutine source libraries and definition
                  files which are absolutely essential for the program.
/bini386        - Contains the executable Tpros program for Linux PCs.
/binsun4        - Contains the executable Tpros program for Sun 4.          
/binsun5        - Contains the executable Tpros program for Sun 5. 
/example        - Contains typical examples; not used for this application.
/spec           - Contains typical specification files; not used for this
                  application.
/weld-toughness - Contains typical examples; not used for this application.

and several files:

Makefile  - The makefile for compiling the program Tpros.c.
randfile  - Absolutely essential for running the software.
README    - A "Readme" file... please read it!
TManual   - Document providing information about Gaussian Processes and
	    Tpros. Very helpful for further use of the software. 
Tpros.c   - The Tpros source code in C.
Tspec     - Typical specification files; not used for this application.
Tspec14   - Typical specification files; not used for this application

                           *** IMPORTANT ***
Place the appropriate version of the Tpros executable file into a Tpros parent 
directory (in this case /gauss). If neither of these versions is suitable, the 
source code can be recompiled using the Makefile.

2.2 The Data Files from MAP
---------------------------

The nipros.tar file from MAP contains the following files:

unnorm.f         - A FORTRAN program for un-normalising the output data files.
nipros.man       - This manual.
paper.rtf        - A file containing the paper in reference 1 in rtf format.
h           	 - Hyperparameters file.
inputs.norm      - Normalised inputs file (composition and test temperature of
		   alloys in the database).
min-max	         - Minimum and maximum values for the wt.% of each element and 
                   the temperature (degrees C) used in the original database
		   (i.e. the minimum and maximum values of each column in the
		   original database before normalisation).
output.norm  	 - Normalised yield stress values.
TspecNi		 - Tpros specification file for predictions.

The following files are essential for using the Tpros program for predicting the 
yield stress, and should be placed in the parent Tpros directory with the Tpros
executable program:

h
inputs.norm
output.norm
TspecNi

These files should not be changed. The file inputs.norm contains 192 lines of 
normalised data, specifying a range of different alloys compositions and test 
temperatures. The file output.norm contains the normalised experimentally 
determined values for the yield strength for each entry in the inputs.norm file.
These files were fed into the Gaussian Process model, which produced as output
the file h, containing the parameters of the non-linear, multi-parameter fit to
the data. The Tpros program uses it for predicting values of the yield stress for
other alloy compositions and test temperatures.

The order of the variables in the *.norm files are specified in the file min-max.
Each input and output variable has been linearly normalised to lie in the range 
-0.5 to +0.5 (see Reference 1 and the file min-max for details).

inputs.norm		16 columns, 192 lines. The input data.
output.norm		1 column, 192 lines. The yield stress output data.

##################################################################################
3.                Creating an Input File for the Tpros Program
##################################################################################

The composition and test temperatures of the alloys for which predictions of the
yield stress are to be made should be placed into a file as follows (see also the
file min-max):

Each line of data corresponds to a different alloy composition or test
temperature (there is no restriction on the number of lines of data in the input
file.)

For each alloy, 16 data items must be specified:

Column number	    Variable

    1		normalised Ni wt.%
    2		normalised Cr wt.%	
    3		normalised Co wt.%	
    4		normalised Mo wt.%	
    5		normalised W  wt.%	
    6		normalised Ta wt.%	
    7		normalised Nb wt.%	
    8		normalised Al wt.%	
    9		normalised Ti wt.%	
   10		normalised Fe wt.%	
   11		normalised Mn wt.%	
   12		normalised Si wt.%	
   13		normalised C  wt.%	
   14		normalised B  wt.%	
   15		normalised Zr wt.%	
   16		normalised test temperature (degrees C)

The actual composition (in wt.%) must be normalised using the equation:

                    (value - Min)
normalised value =  -------------   - 0.5
                     (Max - Min)

where the values for Min and Max are defined as follows:
		
Column number	Variable		Min	Max

      1		Ni (wt.%)		38	76
      2		Cr  ,,			12	30
      3		Co  ,,			0	20
      4		Mo  ,,			0	10
      5		W   ,,			0	6
      6		Ta  ,,			0	1.5
      7		Nb  ,,			0	6.5
      8		Al  ,,			0	4.9
      9		Ti  ,,			0	5
     10		Fe  ,,			0	40
     11		Mn  ,,			0	0.5
     12		Si  ,,			0	0.5
     13		C   ,,			0.03	0.35
     14		B   ,,			0	0.16
     15		Zr  ,,			0	0.2
     16		Test temperature	21	1093
		(degrees C)

A sample data file
------------------

For a set of alloys with the following wt.% and test temperatures (degrees C): 

  Ni   Cr  Co  Mo   W  Ta  Nb  Al  Ti  Fe  Mn   Si    C   B    Zr  Temperature
72.69  10   8   5   0   0   0   3   1   0   0  0.2  0.10 0.01   0  21
65.58  15  11   4   0   0   0   3   1   0   0  0.3  0.11 0.01   0  21
70.79  12  10   3   0   0   0   3   1   0   0  0.1  0.10 0.01   0  750
69.77  14  10   2   0   0   0   3   1   0   0  0.1  0.12 0.01   0  750
69.70  15  10   1   0   0   0   3   1   0   0  0.2  0.09 0.01   0  750
72.35  20   0   0   1   0   0   1   5   0   0  0.4  0.23 0.02   0  900
72.71  20   0   0   1   0   0   2   4   0   0  0.2  0.25 0.02   0  900
59.48  25   8   0   1   0   0   3   3   0   0  0.3  0.20 0.02   0  650
67.44  25   0   0   1   0   0   4   2   0   0  0.3  0.23 0.03   0  650
65.51  27   0   0   1   0   0   5   1   0   0  0.2  0.26 0.03   0  650
 
The input file is:

0.41289 -0.61111 -0.1   0   -0.5     -0.5 -0.5  0.11224 -0.3 -0.5 -0.5 -0.1 -0.25    -0.4375 -0.5 -0.5
0.22579 -0.33333  0.05 -0.1 -0.5     -0.5 -0.5  0.11224 -0.3 -0.5 -0.5  0.1 -0.21875 -0.4375 -0.5 -0.5
0.36289 -0.5      0    -0.2 -0.5     -0.5 -0.5  0.11224 -0.3 -0.5 -0.5 -0.3 -0.25    -0.4375 -0.5  0.18004
0.33605 -0.38889  0    -0.3 -0.5     -0.5 -0.5  0.11224 -0.3 -0.5 -0.5 -0.3 -0.1875  -0.4375 -0.5  0.18004
0.33421 -0.33333  0    -0.4 -0.5     -0.5 -0.5  0.11224 -0.3 -0.5 -0.5 -0.1 -0.28125 -0.4375 -0.5  0.18004
0.40395 -0.05556 -0.5  -0.5 -0.33333 -0.5 -0.5 -0.29592  0.5 -0.5 -0.5  0.3  0.15625 -0.375  -0.5  0.31996
0.41342 -0.05556 -0.5  -0.5 -0.33333 -0.5 -0.5 -0.09184  0.3 -0.5 -0.5 -0.1  0.21875 -0.375  -0.5  0.31996
0.06526  0.22222 -0.1  -0.5 -0.33333 -0.5 -0.5  0.11224  0.1 -0.5 -0.5  0.1  0.0625  -0.375  -0.5  0.086754
0.27474  0.22222 -0.5  -0.5 -0.33333 -0.5 -0.5  0.31633 -0.1 -0.5 -0.5  0.1  0.15625 -0.3125 -0.5  0.086754
0.22395  0.33333 -0.5  -0.5 -0.33333 -0.5 -0.5  0.52041 -0.3 -0.5 -0.5 -0.1  0.25    -0.3125 -0.5  0.086754

##################################################################################
4.                         Running the Tpros Program
##################################################################################

The input file (see section 3.) should be placed in the Tpros parent directory along
with the executable program and the other required data files (see section 2.). The 
command line for running Tpros is of the form:

Tpros (Tspec filename) -hi (hyperparameter filename) -ninter (no. of lines of input 
data) -int_gf (input data filename) -int_of (output filename)

If the name of the input file is 'pred.norm' and has 10 lines of data (as in section
3 above), a suitable command line for running the Tpros program is then

Tpros TspecNi -hi h -ninter 10 -int_gf pred.norm -int_of pred.res.norm

The output file pred.res.norm is produced and contains the calculated yield
strengths in normalised form.

Predictions can take several minutes... , depending on the length of your input
file, and the power of your computer!

##################################################################################
5.                             The Output File
##################################################################################

The predicted values for the yield strength produced by the Tpros program are 
written to a file called pred.res.norm. This output file contains 1 line of 5 data
items for each line of input data:

column 1 - the normalised predicted yield strength.
column 2 - the 1-sigma error bar, which includes both the experimental noise
           of the database and an estimation of the prediction uncertainty.
column 3 - the predicted output minus the 1-sigma error.
column 4 - the predicted output plus the 1-sigma error.
column 5 - an estimation of the noise level in the database; it is the same for
           all lines.

The normalised values for the yield strength in columns 1, 3 and 4, must be 
un-normalised using the equation:

       actual value = [(normalised value + 0.5)*(Max - Min)] + Min

The values in column 2 can be un-normalised using the equation:

            actual value = normalised value * (Max - Min)

The values of Min and Max for the yield stress are 28 MPa and 1310 MPa, 
respectively. The FORTRAN program, unnorm.f, can be used to translate the output 
file to produce the actual values of the yield stress (it must be compiled first).

Sample Output
-------------

When running the Tpros program the following is output to the screen:

Tpros : GP training program
===========================

(c)1996,1997 M N Gibbs and D J C MacKay

Version 6.2


specfile    : TspecNi
datafile    : output.norm
gridfile    : inputs.norm
outfile     : pred.res.norm
hypinfile       : h

Parameter values

SEED                             : 680
no. of initial data points       : 192
no. of dimensions in input space : 16
no. of gaussians in cov fn       : 1
order of polynomials for l.s.    : 1


igridfile                        : pred.norm
Method used for inversion (INT)  : LUd
no. of interpolation points      : 10
no. of s.d. for error bars       : 1
Calculate Error Bars             : yes
Calculate noise                  : yes


no. of hidden neurons noise : 1

Train Error  : 0.103859

                               ------------------

A sample output file pred.res.norm, obtained using the sample input file in
section 3., is:

 0.005423 0.066927 -0.061504  0.072351 0.030084 
-0.000309 0.062081 -0.062390  0.061772 0.030084 
-0.128383 0.059650 -0.188032 -0.068733 0.030084 
-0.147786 0.060995 -0.208781 -0.086791 0.030084 
-0.146840 0.064468 -0.211307 -0.082372 0.030084 
-0.203048 0.118880 -0.321929 -0.084168 0.030084 
-0.257969 0.096652 -0.354621 -0.161317 0.030084 
-0.002483 0.075561 -0.078044  0.073078 0.030084 
-0.067076 0.092816 -0.159892  0.025740 0.030084 
-0.096879 0.120929 -0.217808  0.024050 0.030084 


This output data can be translated using the formulae given above or with the
FORTRAN progran unnorm.f to give the actual values for the yield stress:

 Yield strength   Error    Range of values for 
      (MPa)                yield strength (MPa)
     675.95       85.80     590.15  -   761.75
     668.60       79.59     589.02  -   748.19
     504.41       76.47     427.94  -   580.88
     479.54       78.20     401.34  -   557.73
     480.75       82.65     398.10  -   563.40
     408.69      152.40     256.29  -   561.10
     338.28      123.91     214.38  -   462.19
     665.82       96.87     568.95  -   762.69
     583.01      118.99     464.02  -   702.00
     544.80      155.03     389.77  -   699.83

##################################################################################
6.                 References and Other Sources of Information                    
##################################################################################

1. F. Tancret, H.K.D.H. Bhadeshia and D.J.C. MacKay, "Comparison of artificial
   neural networks with Gaussian processes to model the yield strength of
   nickel-base superalloys", ISIJ International, 1999 (in press).

   This paper explains the yield stress modelling problem, the dataset, the basics
   of Gaussian Process modelling, as well as presenting results from its use and a
   comparison with predictions made with neural networks.

Further information about Gaussian Processes can be obtained from:

2. The references in reference 1.
3. Mark Gibbs' Gaussian Processes web page: 
            http://wol.ra.phy.cam.ac.uk/mng10/GP/GP.html
   The Tpros software can also be downloaded from here.
4. David MacKay's Gaussian Processes web page:
            http://wol.ra.phy.cam.ac.uk/mackay/GP/
5. A short summary by Coryn Bailer-Jones:
            http://www.mpia-hd.mpg.de/stars/calj/gp_sum.ps.gz

